iterationtools.iterate_timeline_from_component
==============================================

.. autofunction:: abjad.tools.iterationtools.iterate_timeline_from_component.iterate_timeline_from_component
   :noindex:
